<- Back to shtanton's homepage
aboutsummaryrefslogtreecommitdiff
path: root/subex/subexast.go
diff options
context:
space:
mode:
Diffstat (limited to 'subex/subexast.go')
-rw-r--r--subex/subexast.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/subex/subexast.go b/subex/subexast.go
index f5b1178..f4088fe 100644
--- a/subex/subexast.go
+++ b/subex/subexast.go
@@ -195,13 +195,13 @@ func (ast SubexASTCopyString) String() string {
return "#"
}
// Read in a value and copy it out unchanged
// , is equivalent to `null`|?|%|#|[`{}[]`]
type SubexASTCopyValue struct {}
func (ast SubexASTCopyValue) compileWith(next SubexState, slotMap *SlotMap) SubexState {
return &SubexGroupState {
SubexASTCopyString{}.compileWith(next, slotMap),
- &SubexCopyNonStringAtomState {next},
+ &SubexCopyNonStringNonTerminalAtomState {next},
}
}
func (ast SubexASTCopyValue) String() string {
@@ -195,13 +195,13 @@ func (ast SubexASTCopyString) String() string {
return "#"
}
-// Read in a value and copy it out unchanged
-// , is equivalent to `null`|?|%|#|[`{}[]`]
+// Read in a non-terminal value and copy it out unchanged
+// , is equivalent to `null`|?|%|#
type SubexASTCopyValue struct {}
func (ast SubexASTCopyValue) compileWith(next SubexState, slotMap *SlotMap) SubexState {